+ git-libata-pata_cs5535-is-not-bust.patch added to -mm tree

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



The patch titled

     git-libata-pata_cs5535-is-not-bust

has been added to the -mm tree.  Its filename is

     git-libata-pata_cs5535-is-not-bust.patch

See http://www.zip.com.au/~akpm/linux/patches/stuff/added-to-mm.txt to find
out what to do about this

------------------------------------------------------
Subject: git-libata-pata_cs5535-is-not-bust
From: Alan Cox <alan@xxxxxxxxxxxxxxxxxxx>


Doh.

Signed-off-by: Alan Cox <alan@xxxxxxxxxx>
Signed-off-by: Andrew Morton <akpm@xxxxxxxx>
---

 drivers/scsi/pata_cs5535.c |   10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff -puN drivers/scsi/pata_cs5535.c~git-libata-pata_cs5535-is-not-bust drivers/scsi/pata_cs5535.c
--- a/drivers/scsi/pata_cs5535.c~git-libata-pata_cs5535-is-not-bust
+++ a/drivers/scsi/pata_cs5535.c
@@ -39,7 +39,7 @@
 #include <asm/msr.h>
 
 #define DRV_NAME	"cs5535"
-#define DRV_VERSION	"0.2.9"
+#define DRV_VERSION	"0.2.10"
 
 /*
  *	The Geode (Aka Athlon GX now) uses an internal MSR based
@@ -70,14 +70,14 @@
 #define CS5535_BAD_PIO(timings) ( (timings&~0x80000000UL)==0x00009172 )
 
 /**
  *	cs5535_cable_detect		-	detect cable type
  *	@ap: Port to detect on
  *
  *	Perform cable detection for ATA66 capable cable. Return a libata
  *	cable type.
  */
 
-static int cs5535_probe_init(struct ata_port *ap)
+static int cs5535_pre_reset(struct ata_port *ap)
 {
 	u8 cable;
 	struct pci_dev *pdev = to_pci_dev(ap->host_set->dev);
@@ -87,7 +87,7 @@ static int cs5535_probe_init(struct ata_
 		ap->cbl = ATA_CBL_PATA80;
 	else
 		ap->cbl = ATA_CBL_PATA40;
-	return ata_std_probeinit(ap);
+	return ata_std_prereset(ap);
 }
 
 /**
@@ -99,7 +99,7 @@ static int cs5535_probe_init(struct ata_
 
 static void cs5535_error_handler(struct ata_port *ap)
 {
-	ata_bmdma_drive_eh(ap, cs5535_probe_init, ata_std_softreset, NULL, ata_std_postreset);
+	ata_bmdma_drive_eh(ap, cs5535_pre_reset, ata_std_softreset, NULL, ata_std_postreset);
 }
 
 /**
_

Patches currently in -mm which might be from alan@xxxxxxxxxxxxxxxxxxx are

git-libata-all.patch
git-libata-all-data_xfer-fixes.patch
git-libata-all-data_xfer-fixes-fixes.patch
git-libata-pata_cs5535-is-not-bust.patch
git-libata-pata_cs5535-is-bust.patch
via-pata-fails-on-some-atapi-drives.patch
via-pata-fails-on-some-atapi-drives-tidy.patch
git-pcmcia.patch
megaraid-gcc-41-warning-fix.patch
bogus-disk-geometry-on-large-disks.patch
m68k-completely-initialize-hw_regs_t-in-ide_setup_ports.patch
more-bug_on-conversion.patch
idetape-gcc-41-warning-fix.patch
ide-cd-end-of-media-error-fix.patch
moxa-remove-pointless-check-of-tty-argument-vs-null.patch
moxa-partial-codingstyle-cleanup-spelling-fixes.patch
correct-tty-doc.patch
fix-memory-leak-in-rocketport-rp_do_receive.patch
ata-add-some-nvidia-chipset-ids.patch
ide-pdc202xx_oldc-remove-unneeded-tuneproc-call.patch
ide-claim-extra-dma-ports-regardless-of-channel.patch
ide-remove-dma_base2-field-form-ide_hwif_t.patch
ide-always-release-dma-engine.patch
ide-error-handling-fixes.patch
ide-hpt3xxn-clocking-fixes.patch
ide-io-increase-timeout-value-to-allow-for-slave-wakeup.patch
ide-actually-honor-drives-minimum-pio-dma-cycle-times.patch
ide-fix-hpt37x-timing-tables.patch
ide-optimize-hpt37x-timing-tables.patch
ide-fix-hpt3xx-hotswap-support.patch
ide-fix-the-case-of-multiple-hpt3xx-chips-present.patch
ide-hpt3xx-fix-pci-clock-detection.patch
ide-hpt3xx-fix-pci-clock-detection-fix-2.patch
ide-pdc202xx_old-remove-the-obsolete-busproc.patch
piix-fix-82371mx-enablebits.patch
piix-remove-check-for-broken-mw-dma-mode-0.patch
piix-slc90e66-pio-mode-fallback-fix.patch
make-number-of-ide-interfaces-configurable.patch
ide_dma_speed-fixes.patch
ide_dma_speed-fixes-warning-fix.patch
ide_dma_speed-fixes-tidy.patch
hpt3xx-rework-rate-filtering.patch
hpt3xx-rework-rate-filtering-tidy.patch
hpt3xx-print-the-real-chip-name-at-startup.patch
hpt3xx-switch-to-using-pci_get_slot.patch
hpt3xx-cache-channels-mcr-address.patch
hpt3x7-merge-speedproc-handlers.patch
fix-ide-deadlock-in-error-reporting-code.patch
hpt370-clean-up-dma-timeout-handling.patch
hpt370-clean-up-dma-timeout-handling-cleanup.patch
pdc202xx_old-depends-on-config_blk_dev_idedma.patch
remove-code-that-has-long-been-commented-out-from-pdc20265_old.patch
enable-cdrom-dma-access-with-pdc20265_old.patch
ide-fix-revision-comparison-in-ide_in_drive_list.patch
revert-tty-buffering-comment-out-debug-code.patch

-
@@ -70,14 +70,14 @@
 
 /**
- *	cs5535_cable_detect		-	detect cable type
+ *	cs5535_pre_reset	-	detect cable type
  *	@ap: Port to detect on
  *
To unsubscribe from this list: send the line "unsubscribe mm-commits" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html

[Index of Archives]     [Kernel Newbies FAQ]     [Kernel Archive]     [IETF Annouce]     [DCCP]     [Netdev]     [Networking]     [Security]     [Bugtraq]     [Photo]     [Yosemite]     [MIPS Linux]     [ARM Linux]     [Linux Security]     [Linux RAID]     [Linux SCSI]

  Powered by Linux